@@ -9,13 +9,14 @@ require DynaLoader;
 use vars qw(@ISA %EXPORT_TAGS @EXPORT_OK $VERSION);
 @ISA = qw(DynaLoader);
 
-$VERSION = '0.32_05';
+$VERSION = '0.32_06';
 
 %EXPORT_TAGS = (
     'all' => [qw(
         &clear &compare &copy &generate &generate_random &generate_time
-        &generate_v1 &generate_v4 &is_null &parse &time &type &unparse
-        &unparse_lower &unparse_upper &uuid &uuid1 &uuid4 &variant
+        &generate_v1 &generate_v4 &generate_v6 &is_null &parse &time
+        &type &unparse &unparse_lower &unparse_upper &uuid &uuid1 &uuid4
+        &uuid6 &variant
     )],
 );
 
@@ -59,35 +60,34 @@ UUID - Universally Unique Identifier library for Perl
 
 =head1 SYNOPSIS
 
-    use UUID 'uuid';
+    use UUID qw(uuid uuid1 uuid4);    # see EXPORTS
 
-    $string = uuid();   # generate UUID string, prefer v4, fallback v1
-    $string = uuid1();  # generate UUID string, always v1
-    $string = uuid4();  # generate UUID string, always v4
+    $str = uuid();                    # new stringified UUID; prefer v4
+    $str = uuid1();                   # new stringified UUID; always v1
+    $str = uuid4();                   # new stringified UUID; always v4
 
-    UUID::generate_v1($uuid);            # new version 1 binary UUID
-    UUID::generate_v4($uuid);            # new version 4 binary UUID
+    UUID::generate($bin);             # new binary UUID; prefer v4
+    UUID::generate_v1($bin);          # new binary UUID; always v1
+    UUID::generate_v4($bin);          # new binary UUID; always v4
 
-    UUID::generate($uuid);               # new binary UUID; prefer v4
-    UUID::generate_time($uuid);          # alias for generate_v1()
-    UUID::generate_random($uuid);        # alias for generate_v4()
+    UUID::generate_time($bin);        # alias for generate_v1()
+    UUID::generate_random($bin);      # alias for generate_v4()
 
-    UUID::unparse($uuid, $string);       # stringify $uuid; system casing
-    UUID::unparse_lower($uuid, $string); # force lowercase stringify
-    UUID::unparse_upper($uuid, $string); # force uppercase stringify
+    UUID::unparse($bin, $str);        # stringify $bin; prefer lowercase
+    UUID::unparse_lower($bin, $str);  # force lowercase stringify
+    UUID::unparse_upper($bin, $str);  # force uppercase stringify
 
-    $rc = UUID::parse($string, $uuid);   # map string to UUID; -1 on error
+    UUID::parse($str, $bin);          # map string to binary UUID
 
-    UUID::copy($dst, $src);              # copy binary UUID from $src to $dst
-    UUID::compare($uuid1, $uuid2);       # compare binary UUIDs
+    UUID::compare($bin1, $bin2);      # compare binary UUIDs
+    UUID::copy($dst, $src);           # copy binary UUID from $src to $dst
 
-    UUID::clear( $uuid );                # set binary UUID to NULL
-    UUID::is_null( $uuid );              # compare binary UUID to NULL
+    UUID::clear($bin);                # set binary UUID to NULL
+    UUID::is_null($bin);              # compare binary UUID to NULL
 
-    UUID::type( $uuid );                 # return UUID type
-    UUID::variant( $uuid );              # return UUID variant
-
-    UUID::time( $uuid );                 # return internal UUID time
+    UUID::time($bin);                 # return UUID time
+    UUID::type($bin);                 # return UUID type
+    UUID::variant($bin);              # return UUID variant
 
 
 =head1 DESCRIPTION
@@ -102,18 +102,18 @@ system, and unique across all systems, and are compatible with those
 created by the Open Software Foundation (OSF) Distributed Computing
 Environment (DCE).
 
-All generated UUIDs are either version 1 from B<generate_v1()>, or
-version 4 from B<generate_v4()>. And all are variant 1, meaning
-compliant with the OSF DCE standard as described in RFC4122.
+All generated UUIDs are either version 1 or version 4. And all are
+variant 1, meaning compliant with the OSF DCE standard as described
+in RFC4122.
 
 =head1 FUNCTIONS
 
-Most of the UUID functions expose the underlying I<libuuid> C interface
-rather directly. That is, many return their values in their parameters
-and nothing else.
+Most of the UUID functions expose the historically underlying
+I<libuuid> C interface rather directly. That is, many return their
+values in their parameters and nothing else.
 
-Not very Perlish, is it? It's been like that for a long time though, so
-not very likely to change any time soon.
+Not very Perlish, is it? It's been like that for a long time now,
+so not likely to change any time soon.
 
 All take or return UUIDs in either binary or string format. The string
 format resembles the following:
@@ -130,12 +130,6 @@ The binary form is simply a packed 16 byte binary value.
 
 Sets I<$uuid> equal to the value of the NULL UUID.
 
-=head2 B<copy(> I<$dst>B<,> I<$src> B<)>
-
-Copies the binary I<$src> UUID to I<$dst>.
-
-If I<$src> isn't a UUID, I<$dst> is set to the NULL UUID.
-
 =head2 B<compare(> I<$uuid1>B<,> I<$uuid2> B<)>
 
 Compares two binary UUIDs.
@@ -146,6 +140,12 @@ I<$uuid1> is less than, equal to, or greater than I<$uuid2>.
 However, if either operand is not a UUID, falls back to a simple string
 comparison returning similar values.
 
+=head2 B<copy(> I<$dst>B<,> I<$src> B<)>
+
+Copies the binary I<$src> UUID to I<$dst>.
+
+If I<$src> isn't a UUID, I<$dst> is set to the NULL UUID.
+
 =head2 B<generate(> I<$uuid> B<)>
 
 Generates a new version 4 binary UUID based on high quality randomness
@@ -278,9 +278,9 @@ Known variants:
 
 Internal state is optionally maintained for version 1 UUIDs via a file
 designated by the B<:persist> export tag (see EXPORTS), if the path
-exists and the user running the process has read/write access.
+exists and the user running the process has read/write permission.
 
-If the file doesn't exist, it will be created if the directory path
+If the file doesn't exist, it is created if the directory path
 exists.
 
 The file records various internal states at the time the last UUID is
@@ -288,16 +288,16 @@ generated, preventing future instances from overlapping the prior UUID
 sequence. This allows the sequence to absolutely survive reboots and,
 more importantly, backwards resetting of system time.
 
-If B<:persist> is not used, time resets will still be detected while the
-module is loaded, and handled accordingly. And since startup in this
-case is randomized anyway, the chance of overlap is low but still exists
-since the randomized clock_seq field is only 14 bits wide.
+If B<:persist> is not used, time resets will still be detected while
+the module is loaded and handled accordingly. And since startup in
+this case is randomized anyway, the chance of overlap is low but
+still exists. The randomized clock_seq field is 14 bits wide.
 
 Note that use of this feature incurs a serious performance penalty,
 upwards of 90% on tested platforms.
 
-Note too that use of a random MAC greatly reduces the chance of overlap,
-making the randomized parts 62 bits wide at start.
+Note too that use of a random MAC greatly reduces the chance of
+overlap. The randomized fields total 62 bits at start.
 
 =head1 EXPORTS
 
@@ -326,7 +326,7 @@ Path to version 1 state maintenance file. (See B<MAINTAINING STATE>.)
 The path may be either relative or absolute.
 
 If the file does not exist, it will be created provided the path
-exists.
+exists and the user has permission.
 
 If the file cannot be opened, cannot be created, or is a symlink, UUID
 will ignore it. No state will be maintained.
@@ -342,8 +342,8 @@ This module is believed to be thread safe.
 =head1 UUID LIBRARY
 
 Releases prior to UUID-0.32 required libuuid or similar be installed
-first. This is no longer the case. UUID now builds against a bundled
-copy of the e2fsprogs UUID code.
+first. This is no longer the case. Version 0.33 bundled the e2fsprogs
+UUID code, and version 0.34 removed it altogether.
 
 =head1 COPYRIGHT AND LICENSE
 
