@@ -9,6 +9,7 @@
 use strict;
 use warnings;
 use Config;
+use File::Spec;
 use File::Temp ();
 use Devel::CheckLib;
 
@@ -40,36 +41,36 @@ sub generate_conf {
     for my $check ( 1, 0 ) {
         try_headers($check, \$longest, $defines, qw(
             HAVE_CTYPE_H         ctype.h
-            -HAVE_ERR_H           err.h
+            HAVE_ERR_H           err.h
             HAVE_ERRNO_H         errno.h
-            HAVE_FCNTL_H         fcntl.h
+            -HAVE_FCNTL_H         fcntl.h
             HAVE_INTTYPES_H      inttypes.h
             HAVE_IO_H            io.h
-            -HAVE_NETINET_IN_H    netinet/in.h
+            HAVE_NETINET_IN_H    netinet/in.h
             HAVE_NET_IF_DL_H     net/if_dl.h
             HAVE_NET_IF_H        net/if.h
-            -HAVE_PROCESS_H       process.h
-            -HAVE_STDINT_H        stdint.h
+            HAVE_PROCESS_H       process.h
+            HAVE_STDINT_H        stdint.h
             HAVE_STDIO_H         stdio.h
             HAVE_STDLIB_H        stdlib.h
             HAVE_STRING_H        string.h
-            -HAVE_SYS_FILE_H      sys/file.h
+            HAVE_SYS_FILE_H      sys/file.h
             HAVE_SYS_IOCTL_H     sys/ioctl.h
-            -HAVE_SYS_RANDOM_H    sys/random.h
-            -HAVE_SYS_RESOURCE_H  sys/resource.h
+            HAVE_SYS_RANDOM_H    sys/random.h
+            HAVE_SYS_RESOURCE_H  sys/resource.h
             HAVE_SYS_SOCKET_H    sys/socket.h
-            -HAVE_SYS_SOCKIO_H    sys/sockio.h
+            HAVE_SYS_SOCKIO_H    sys/sockio.h
             HAVE_SYS_STAT_H      sys/stat.h
             HAVE_SYS_TIME_H      sys/time.h
             HAVE_SYS_TYPES_H     sys/types.h
-            -HAVE_SYS_WAIT_H      sys/wait.h
-            -HAVE_TIME_H          time.h
+            HAVE_SYS_WAIT_H      sys/wait.h
+            HAVE_TIME_H          time.h
             HAVE_UNISTD_H        unistd.h
             HAVE_WINDOWS_H       Windows.h
         ));
 
-        #try_getentropy   ($check, \$longest, $defines);
-        #try_getrandom    ($check, \$longest, $defines);
+        try_getentropy   ($check, \$longest, $defines);
+        try_getrandom    ($check, \$longest, $defines);
         try_lstat        ($check, \$longest, $defines);
         try_symlink      ($check, \$longest, $defines);
 
@@ -82,6 +83,9 @@ sub generate_conf {
 
         # requires $WIN32.
         try_threads      ($check, \$longest, $defines);
+
+        # do this last, just to be safe.
+        try_u64          ($check, \$longest, $defines);
     }
 #
 # these havent been handled yet. do they need to be?
@@ -407,6 +411,42 @@ sub try_threads {
     unlink $conf1, $conf2;
 }
 
+sub try_u64 {
+    my ($check, $long, $defs) = @_;
+    my $msg = 'Checking U64 type';
+    my $len = length $msg;
+    if ($check) { $$long = $len if $len > $$long; return; }
+    my $more = $$long - $len;
+
+    my ($conf, $fh) = gen_confh_fh($defs);
+    print $fh join("\n", map {s/^\s+//;$_} split(/\n/, q{
+        #include "EXTERN.h"
+        #include "perl.h"
+    }));
+    close $fh;
+
+    if ( check_lib(
+        header   => $conf,
+        lib      => 'c', # always do at least this
+        incpath  => ['.', File::Spec->catdir($Config{archlib}, 'CORE')],
+        #ccflags  => '-Wno-compound-token-split-by-macro',
+        debug    => 0,
+        function => q{
+            U64 x;
+            x = 0;
+            return x;
+        },
+    )) {
+        push @$defs, '#define HAVE_TYPE_U64 1';
+        print $msg, ' ..', '.'x$more, ' found';
+    }
+    else {
+        push @$defs, '#undef HAVE_TYPE_U64';
+        print $msg, ' ..', '.'x$more, ' missing';
+    }
+    unlink $conf;
+}
+
 sub write_conf {
     my ($defines, $outfile) = @_;
 
