@@ -1,17 +1,19 @@
 use strict;
 use warnings;
 use Benchmark qw(:hireswallclock cmpthese countit);
-use UUID qw(generate_v1 generate_v4 uuid1 uuid4 unparse);
+use UUID qw(generate_v1 generate_v4 generate_v6 uuid1 uuid4 uuid6 unparse);
 
 my $seconds = $ARGV[0] || 1;
 
 print "\ncomparing speeds...\n\n";
 
 my $r = cmpthese({
-    'v4str' => countit($seconds, 'my $s = uuid4()'),
-    'v4bin' => countit($seconds, 'generate_v4(my $b)'),
-    'v1str' => countit($seconds, 'my $s = uuid1()'),
     'v1bin' => countit($seconds, 'generate_v1(my $b)'),
+    'v1str' => countit($seconds, 'my $s = uuid1()'),
+    'v4bin' => countit($seconds, 'generate_v4(my $b)'),
+    'v4str' => countit($seconds, 'my $s = uuid4()'),
+    'v6bin' => countit($seconds, 'generate_v6(my $b)'),
+    'v6str' => countit($seconds, 'my $s = uuid6()'),
 }, 'none');
     #'v1testS'  => countit($seconds, 'my $s = UUID::_v1testS()'),
     #'v1testB'  => countit($seconds, 'UUID::_v1testB(my $b)'),
@@ -19,14 +21,16 @@ my $r = cmpthese({
     #'v4testB'  => countit($seconds, 'UUID::_v4testB(my $b)'),
 
 #printf("%9s %11s %7s %7s %7s %7s %7s %7s %7s %7s\n", @$_) for @$r;
-printf("%9s %11s %6s %6s %6s %6s\n", @$_) for @$r;
+printf("%9s %11s %6s %6s %6s %6s %6s %6s\n", @$_) for @$r;
 
 print <<'EOT';
 
     v1bin  ->  eval 'generate_v1(my $b)'
     v4bin  ->  eval 'generate_v4(my $b)'
+    v6bin  ->  eval 'generate_v6(my $b)'
     v1str  ->  eval 'my $s = uuid1()'
     v4str  ->  eval 'my $s = uuid4()'
+    v6str  ->  eval 'my $s = uuid6()'
 EOT
 
 print "\n\ncomparing calling styles...\n\n";
