@@ -7,5 +7,9 @@ void uu_unparse_lower(const struct uu *in, char *out);
 void uu_unparse_upper(const struct uu *in, char *out);
 void uu_unparse(const struct uu *in, char *out);
 
+void uu_unparse_lower6(const struct uu6 *in, char *out);
+void uu_unparse_upper6(const struct uu6 *in, char *out);
+void uu_unparse6(const struct uu6 *in, char *out);
+
 #endif
 /* ex:set ts=2 sw=2 itab=spaces: */
